@@ -33,6 +33,22 @@ TOnRpcData = WINFUNCTYPE(None,ps32,size_t)
 # Arg[1] ADataId
 # Arg[2] AValue
 TOnAutoSARE2ECanEvt = WINFUNCTYPE(None,PLIBCANFD,u32,pu64)
+# Arg[0] AChnIdx
+# Arg[1] APDUName
+# Arg[2] ATimestamp
+# Arg[3] AIsTx
+# Arg[4] AID
+# Arg[5] ADataLength
+# Arg[6] AData
+TOnAutoSARPDUQueueEvent = WINFUNCTYPE(None,s32,pchar,u64,u8,u32,u32,pu8)
+# Arg[0] AChnIdx
+# Arg[1] APDUName
+# Arg[2] AID
+# Arg[3] ASrcDataLength
+# Arg[4] ASrcData
+# Arg[5] ADestDataLength
+# Arg[6] ADestData
+TOnAutoSARPDUPreTxEvent = WINFUNCTYPE(s32,s32,pchar,u32,u32,pu8,pu32,pu8)
 # Arg[0] AVidPid
 # Arg[1] ASerial
 TOnUSBPlugEvent = WINFUNCTYPE(None,pchar,pchar)
