@@ -34,6 +34,13 @@ class _TLIBMBDDataType(CEnum):
 TLIBMBDDataType = c_int32
 PLIBMBDDataType = ps32
 
+class _TMBD_PriorityKind(CEnum):
+    mpkPriority = 0
+    mpkFirst = 1
+    mpkLast = 2
+TMBD_PriorityKind = c_int32
+PMBD_PriorityKind = ps32
+
 class _TLIBBusToolDeviceType(CEnum):
     BUS_UNKNOWN_TYPE = 0
     TS_TCP_DEVICE = 1
@@ -59,6 +66,11 @@ class _TLIBApplicationChannelType(CEnum):
     APP_LIN = 1
     APP_FlexRay = 2
     APP_Ethernet = 3
+    APP_AI = 4
+    APP_AO = 5
+    APP_DI = 6
+    APP_DO = 7
+    APP_GPS = 8
 TLIBApplicationChannelType = c_int32
 PLIBApplicationChannelType = ps32
 
